@@ -40,13 +40,8 @@ def parse_config():
         os.path.join(os.path.expanduser("~"), ".sd-upload-config.yaml"),
         "sd-upload-config.yml",
         "sd-upload-config.yaml",
-        os.path.join(os.path.expanduser("~"), ".config", "sd-upload", "sd-upload-config.yml"),
-        os.path.join(os.path.expanduser("~"), ".config", "sd-upload", "sd-upload-config.yaml"),
-        os.path.join(os.path.expanduser("~"), ".config", "sd-upload", "config.yml"),
-        os.path.join(os.path.expanduser("~"), ".config", "sd-upload", "config.yaml"),
-        os.path.join(os.path.expanduser("~"), ".config", "sd-upload", "config"),
-        os.path.join(os.path.expanduser("~"), ".config", "sd-upload", "sd-upload-config"),
-        os.path.join(os.path.expanduser("~"), ".config", "sd-upload", "sd-upload-config"),
+        os.path.join(os.path.expanduser("/opt/robin/config/sd-upload"), "sd-upload-config.yml"),
+        os.path.join(os.path.expanduser("/opt/robin/config/sd-upload"), "sd-upload-config.yaml"),
     ]
 
     config = None
@@ -58,6 +53,7 @@ def parse_config():
             with open(cfg_file, 'r') as config_file:
                 config = yaml.safe_load(config_file)
                 file = cfg_file
+                print(f"Config file found in {cfg_file} directory.")
                 break
         else:
             print(f"Config file not found in {cfg_file} directory.")
